@@ -46,7 +46,7 @@ configureD
 	-> Pin tx
 	-> Baud
 	-> Sketch ()
-configureD d@(SerialDeviceName devname) (Pin (PinId rxpin)) (Pin (PinId txpin)) (Baud n) = do
+configureD d@(SerialDeviceName devname) (Pin (Arduino rxpin)) (Pin (Arduino txpin)) (Baud n) = do
 	baudD d n
 	tell [(\_ -> return (), \_ -> f)]
   where
@@ -67,7 +67,7 @@ configureD d@(SerialDeviceName devname) (Pin (PinId rxpin)) (Pin (PinId txpin))
 
 newtype SerialDevice = SerialDevice SerialDeviceName
 
-instance Input PinId SerialDevice Int8 where
+instance Input Arduino SerialDevice Int8 where
 	input' (SerialDevice (SerialDeviceName devname)) interpretvalues =
 		mkInput s
 	  where
@@ -89,10 +89,10 @@ instance Input PinId SerialDevice Int8 where
 noInput :: Int8
 noInput = -1
 
-instance Output PinId SerialDevice [FormatOutput] where
+instance Output Arduino SerialDevice [FormatOutput] where
 	sdn =: l = sdn =: (Event l true :: Event () [FormatOutput])
 
-instance Output PinId SerialDevice (Event () [FormatOutput]) where
+instance Output Arduino SerialDevice (Event () [FormatOutput]) where
 	SerialDevice sdn@(SerialDeviceName devname) =: (Event l c) = do
 		u <- getUniqueId "serial"
 		let outputfuncname = uniqueName ("output_" <> devname) u
