@@ -141,7 +141,7 @@ finalizeFramework f =
 		mapMaybe setuppinmode (M.toList $ pinmodes f)
 	in f { setups = pinsetups <> setups f }
   where
-	setuppinmode (PinId n, s)
+	setuppinmode (Arduino n, s)
 		| s == S.singleton OutputMode =
 			setmode n "OUTPUT"
 		| s == S.singleton InputMode =
